@@ -72,3 +72,60 @@ setMethod("coordinates", "STT", function(obj) {
 # }
 # 
 # setMethod("plot", signature(x = "STTDF", y = "missing"), plot.STTDF)
+
+subs.STTDF <- function(x, i, j, ... , drop = FALSE) {
+	missing.i = missing(i)
+	missing.j = missing(j)
+	missing.k = k = TRUE
+	dots = list(...)
+    if (length(dots) > 0) {
+        missing.k = FALSE
+        k = dots[[1]]
+    }
+
+	if (missing.i && missing.j && missing.k)
+		return(x)
+
+	#stop("not yet implemented")
+	# space
+	if (missing.i)
+		i = TRUE
+
+	if (is(i, "Spatial") || is(i, "ST")) {
+		# select trajectories that match
+		i = !is.na(over(x@sp, geometry(i)))
+	} 
+	if (is.logical(i)) {
+		i = rep(i, length.out = length(x@traj))
+		i = which(i)
+	} else if (is.character(i)) { # suggested by BG:
+		i = match(i, row.names(x@sp), nomatch = FALSE)
+	}
+
+	# time
+	if (missing.j)
+		j = rep(TRUE, length=nrow(x@time))
+	else {
+		if (is.logical(j))
+			j = which(j)
+		t = xts(matrix(1:nrow(x@time), dimnames=list(NULL, "timeIndex")), 
+				index(x@time))[j]
+		j = as.vector(t[,1])
+	}
+	
+	if(is.numeric(i))
+		i = 1:nrow(x@time) %in% i
+	if(is.numeric(j))
+		j = 1:nrow(x@time) %in% j
+
+	i = i & j
+
+	x@sp = x@sp[i,]
+	x@time = x@time[i,]
+	x@endTime = x@endTime[i]
+	x@data = x@data[i, k, drop = FALSE]
+	if (drop && length(unique(index(x@time))) == 1)
+		x = addAttrToGeom(x@sp, x@data, match.ID = FALSE)
+	x
+}
+setMethod("[", "STTDF", subs.STTDF)
